<?php
/*
	#####################################
										
		Easify WooCommerce Connector
		http://www.easify.co.uk/		
										
		Copyright (c) 2014 Easify Ltd	
		Released under the GPLv2
										
	#####################################

	**************************
		EASIFY WEB SERVICE	  
	**************************
	
	A web service designed to receive method calls from the EASU server.
	
	The URL of this script is to be placed in the following Easify Option location: 
	'Tools > Options > General > Advanced Server Settings > URL of web services on your web server'
	For example:
	http://localhost/wp-content/plugins/easify/easify_web_service.php
	
	Please Note: The ProductDetails and UploadProduct classes are used by the PHP SoapServer
	so that it can map complex objects being passed as parameters to the web service methods.
	Without these class maps UploadProduct web service calls will fail.
	
	Methods 
	-------
	
	IsPKValid( PK )
	UploadProduct( Product, PK )
	UploadProductInfo( ProductSKU, Picture, HTMLDescription, PK )
	UploadStockLevel( ProductSKU, StockLevel, PK )
	DeleteProduct( ProductSKU, PK )

*/

include(dirname(__FILE__) . '/includes/easify_woocomm_receive.php');

class UploadProduct {
	public $Product; // ProductDetails
	public $PK; // String
}

class ProductDetails {
	public $SKU; // Integer
	public $OurStockCode; // String
	public $ManufacturerStockCode; // String
	public $SupplierStockCode; // String
	public $EANCode; // String
	public $Description; // String
	public $CategoryId; // Int
	public $SubcategoryId; // Int
	public $ManufacturerId; // Int
	public $CostPrice; // Decimal
	public $Notes; // String
	public $StockLevel; // Int
	public $Discontinued; // Boolean
	public $MinimumStockLevel; // Int
	public $ReorderAmount; // Int
	public $ReorderWhenLow; // Boolean
	public $DateStockLevelLastUpdated; // DateTime
	public $DatePriceLastChanged; // DateTime
	public $SupplierId; // Int
	public $RetailMargin; // Double
	public $TradeMargin; // Double
	public $TaxId; // Int
	public $Published; // Boolean
	public $Allocatable; // Boolean
	public $Picture; // String
	public $HTMLDescription; // String
  	Public $Weight; // Double
  	Public $DateAdded; // DateTime
}

function IsPKValid($PK)
{
	// This setting needs to be set in Easify here...
	// 'Tools > Options > General > Advanced Server Settings > Web Service Private Key' 
	// And in WordPress here...
	// 'Admin Control Panel > Settings > Easify Settings > Setup > Easify's Private Key'
	return $PK == get_option('easify_options_setup')['easify_private_key'] ? true : false;
}

function UploadProduct($params)
{
	try {
		// parse parameters
		$valueArray = get_object_vars($params);
		$EasifyProduct = $valueArray["Product"];
		$PK = $valueArray["PK"];
		
		EasifyReceiver::WriteLog("UploadProduct(" . $EasifyProduct->SKU . ")");
		
		// authenticate
		if (!IsPKValid($PK)) {
			EasifyReceiver::WriteLog("ERROR: UploadProduct() Invalid PK Received!");
			return false;
		}
		
		// determine if we insert or update the Easify product
		if (!EasifyReceiver::IsExistingProduct($EasifyProduct->SKU)) {
			// insert new product 
			EasifyReceiver::WriteLog("Insert Product");
			EasifyReceiver::InsertProduct($EasifyProduct);
		} else {
			// update existing product 
			EasifyReceiver::WriteLog("Update Product");
			EasifyReceiver::UpdateProduct($EasifyProduct);
		}
		
		EasifyReceiver::DebugTrace();
		
	} catch(Exception $ex) {
		EasifyReceiver::DebugTrace();
		return new SoapFault("UploadProduct", $ex->getMessage());
	}
}

function UploadProductInfo($params)
{
	try {
		// parse parameters
		$valueArray = get_object_vars($params);
		$EasifySKU = $valueArray["ProductSKU"];
		$Picture = $valueArray["Picture"];
		$HTMLDescription = $valueArray["HTMLDescription"];
		$PK = $valueArray["PK"];
		
		EasifyReceiver::WriteLog("UploadProductInfo(" . $EasifySKU . ")");
		
		// authenticate
		if (!IsPKValid($PK)) {
			EasifyReceiver::WriteLog("ERROR: UploadProductInfo() Invalid PK Received!");
			return false;
		}
		
		if (EasifyReceiver::IsExistingProduct($EasifySKU)) {
			// update existing product
			EasifyReceiver::UpdateProductInfo($EasifySKU, $Picture, $HTMLDescription);
		} else {
			// product doesn't exist, log error message
			EasifyReceiver::WriteLog("UploadProductInfo(" . $EasifySKU . ") - doesn't exist");
		}
		
	} catch(Exception $ex) {
		EasifyReceiver::DebugTrace();
		return new SoapFault("UploadProductInfo", $ex->getMessage());
	}
}

function UploadStockLevel($params)
{
	try {
	
		$valueArray = get_object_vars($params);
		$EasifySKU = $valueArray["ProductSKU"];
		$StockLevel = $valueArray["StockLevel"];
		$PK = $valueArray["PK"];
		
		EasifyReceiver::WriteLog("UploadStockLevel(" . $EasifySKU . ", " . $StockLevel . ")");
		
		if (!IsPKValid($PK)) {
			EasifyReceiver::WriteLog("ERROR: UploadStockLevel() Invalid PK Received!");
			return false;
		}
		
		if (EasifyReceiver::IsExistingProduct($EasifySKU)) {
			// update existing product
			EasifyReceiver::UpdateProductStockLevel($EasifySKU, $StockLevel);
		} else {
			// product doesn't exist, log error message
			EasifyReceiver::WriteLog("UploadStockLevel(" . $EasifySKU . ", " . $StockLevel . ") - doesn't exist");
		}
		
	} catch(Exception $ex) {
		EasifyReceiver::DebugTrace();
		return new SoapFault("UploadStockLevel", $ex->getMessage());
	}
}

function DeleteProduct($params)
{
	try {
		
		$valueArray = get_object_vars($params);
		$EasifySKU = $valueArray["ProductSKU"];
		$PK = $valueArray["PK"];
		
		EasifyReceiver::WriteLog("DeleteProduct(". $EasifySKU . ")");		
		
		if (!IsPKValid($PK)) {
			EasifyReceiver::WriteLog("ERROR: DeleteProduct() Invalid PK Received!");
			return false;
		}
		
		if (EasifyReceiver::IsExistingProduct($EasifySKU)) {
			// update existing product
			EasifyReceiver::DeleteProduct($EasifySKU);
		} else {
			// product doesn't exist, log error message
			EasifyReceiver::WriteLog("DeleteProduct(". $EasifySKU . ") - doesn't exist");
		}
		
	} catch(Exception $ex) {
		EasifyReceiver::DebugTrace();
		return new SoapFault("DeleteProduct", $ex->getMessage());
	}
}

// force re-download of WSDL (Web Services Description Language) file before 
// each web service method call, this can slow down each call but has better stability
ini_set("soap.wsdl_cache_enabled", "0");

// maps complex objects being passed as parameters to web service methods 
$Classmap = array(
	"UploadProduct" => "UploadProduct",
	"ProductDetails" => "ProductDetails"
);

// setup web service server, register web service methods then handle current request
$Server = new SoapServer("easify_web_service.wsdl", array("classmap" => $Classmap));
$Server->addFunction("UploadProduct");
$Server->addFunction("UploadProductInfo");
$Server->addFunction("UploadStockLevel");
$Server->addFunction("DeleteProduct");
$Server->handle();

?>