<?php
/*
	#####################################
										
		Easify WooCommerce Connector
		http://www.easify.co.uk/		
										
		Copyright (c) 2014 Easify Ltd	
		Released under the GPLv2
										
	#####################################
	
	*************************
		EASIFY FUNCTIONS	 
	*************************
	
	A set of functions for manipulating Easify via its web services.
	
	Methods
	-------
	
	~ Getters ~
	
		GetEasifyTaxRates() 
		GetEasifyTaxRateDefault()
		GetEasifyProductSubCategoriesByCategory( CategoryId )
		GetEasifyProductCategories()
		GetEasifyCategoryDescriptionFromEasifyCategoryId( EasifyCategoriesOriginal, CategoryId )
		GetEasifyManufacturers()
		
	~ Insert ~ 
		
		InsertEasifyCustomer( EasifyCustomer )
		InsertEasifyOrder( EasifyOrder )
		InsertEasifyOrderItems( EasifyOrderDetails )
		InsertEasifyPayment( EasifyPayment )
		InsertEasifyInternalNotes( EasifyOrderNotes )
		
*/

require_once($_SERVER['DOCUMENT_ROOT'] . '/wp-config.php');
require_once($_SERVER['DOCUMENT_ROOT'] . '/wp-admin/includes/image.php');



/* 
	Getters 
*/

function GetEasifyTaxRates() 
{
	// get a list of Easify tax rates from Easify's orders web service
	$EasifySetupOptions = get_option('easify_options_setup');
	$Client = new SoapClient(
		$EasifySetupOptions['easify_web_service_location'] . "Inbound/EasifyInboundOrders.asmx?wsdl", 
		array("connection_timeout" => $EasifySetupOptions['easify_web_service_timeout']));
	$Tax = $Client->GetTaxRates(array("PK" => $EasifySetupOptions['easify_private_key']));
	return $Tax->GetTaxRatesResult->TaxRates;
}

function GetEasifyTaxRateDefault() 
{
	// get the default Easify tax rate
	$Tax = GetEasifyTaxRates();
	for ($x = 0; $x < sizeof($Tax) - 1; $x++)
		if ($Tax[$x]->IsDefault)
			return $Tax[$x];
	return null;
}

function GetEasifyProductSubCategoriesByCategory($CategoryId) 
{
	// get a list of sub categories from Easify's products web service
	$EasifySetupOptions = get_option('easify_options_setup');
	$Products = new SoapClient(
		$EasifySetupOptions['easify_web_service_location'] . "Inbound/EasifyInboundProducts.asmx?wsdl", 
		array("connection_timeout" => $EasifySetupOptions['easify_web_service_timeout']));
	$Categories = $Products->GetSubCategoriesByCategory(array("PK" => $EasifySetupOptions['easify_private_key'], 
		"CategoryId" => $CategoryId));
	return $Categories->GetSubCategoriesByCategoryResult->SubCategories;
}

function GetEasifyProductCategories()
{
	// get a list of categories from Easify's products web service
	$EasifySetupOptions = get_option('easify_options_setup');
	$Products = new SoapClient(
		$EasifySetupOptions['easify_web_service_location'] . "Inbound/EasifyInboundProducts.asmx?wsdl", 
		array("connection_timeout" => $EasifySetupOptions['easify_web_service_timeout']));
	$Categories = $Products->GetCategories(array("PK" => $EasifySetupOptions['easify_private_key']));
	return $Categories->GetCategoriesResult->Categories;
}

function GetEasifyCategoryDescriptionFromEasifyCategoryId($EasifyCategoriesOriginal, $CategoryId)
{
	// single index arrays of EasifyCategoriesOriginal are passed as objects and need to be converted to an array 
	$EasifyCategories = (sizeof($EasifyCategoriesOriginal) == 1 ? array($EasifyCategoriesOriginal) : $EasifyCategoriesOriginal);
	// match the category description by its id
	for ($i = 0; $i < sizeof($EasifyCategories); $i++)
		if ($EasifyCategories[$i]->Id == $CategoryId)
			return $EasifyCategories[$i]->Description;
	return null;
}

function GetEasifyManufacturers()
{
	// get a list of Manufacturers from Easify's products web service
	$EasifySetupOptions = get_option('easify_options_setup');
	$Products = new SoapClient(
		$EasifySetupOptions['easify_web_service_location'] . "Inbound/EasifyInboundProducts.asmx?wsdl", 
		array("connection_timeout" => $EasifySetupOptions['easify_web_service_timeout']));
	$Manufacturers = $Products->GetManufacturers(array("PK" => $EasifySetupOptions['easify_private_key']));
	return $Manufacturers->GetManufacturersResult->Manufacturers;
}



/* 
	Insert
*/

function InsertEasifyCustomer($EasifyCustomer)
{
	// upload a properly formatted customer array into Easify using the customers web service
	$EasifySetupOptions = get_option('easify_options_setup');
	$client = new SoapClient(
		$EasifySetupOptions['easify_web_service_location'] . "Inbound/EasifyInboundCustomers.asmx?wsdl", 
		array("connection_timeout" => $EasifySetupOptions['easify_web_service_timeout']));
	$client->InsertCustomer($EasifyCustomer);
}

function InsertEasifyOrder($EasifyOrder)
{
	// upload a properly formatted order array into Easify using the orders web service
	$EasifySetupOptions = get_option('easify_options_setup');
	$client = new SoapClient(
		$EasifySetupOptions['easify_web_service_location'] . "Inbound/EasifyInboundOrders.asmx?wsdl", 
		array("connection_timeout" => $EasifySetupOptions['easify_web_service_timeout']));
	$client->InsertOrder(array("Order" => $EasifyOrder, "PK" => $EasifySetupOptions['easify_private_key']));			
}

function InsertEasifyOrderItems($EasifyOrderDetails)
{
	// upload properly formatted order details arrays into Easify using the orders web service
	$EasifySetupOptions = get_option('easify_options_setup');
	$client = new SoapClient(
		$EasifySetupOptions['easify_web_service_location'] . "Inbound/EasifyInboundOrders.asmx?wsdl", 
		array("connection_timeout" => $EasifySetupOptions['easify_web_service_timeout']));
	for ($i = 0; $i < sizeof($EasifyOrderDetails); $i++) {
		$client->InsertOrderItem(array("OrderDetails" => $EasifyOrderDetails[$i], 
		"AllowZeroPrice" => true, "AllowZeroQty" => true, "PK" => $EasifySetupOptions['easify_private_key']));
	}
}

function InsertEasifyPayment($EasifyPayment)
{
	// upload a properly formatted payment array into Easify using the payments web service
	$EasifySetupOptions = get_option('easify_options_setup');
	$client = new SoapClient(
		$EasifySetupOptions['easify_web_service_location'] . "Inbound/EasifyInboundPayments.asmx?wsdl", 
		array("connection_timeout" => $EasifySetupOptions['easify_web_service_timeout']));
	$client->InsertPayment(array("Payment" => $EasifyPayment, "PK" => $EasifySetupOptions['easify_private_key']));
}

function InsertEasifyInternalNotes($EasifyOrderNotes)
{
	// upload a properly formatted order notes array into Easify using the orders web service
	$EasifySetupOptions = get_option('easify_options_setup');
	for ($i = 0; $i < sizeof($EasifyOrderNotes); $i++) {
		$client = new SoapClient(
			$EasifySetupOptions['easify_web_service_location'] . "Inbound/EasifyInboundOrders.asmx?wsdl", 
			array("connection_timeout" => $EasifySetupOptions['easify_web_service_timeout']));
		$client->AddInternalNote(array("ExtOrderNo" => $EasifyOrderNotes[$i]["ExtOrderNo"], 
		"Note" => $EasifyOrderNotes[$i]["Notes"] . "\n\n", "PK" => $EasifySetupOptions['easify_private_key']));
	}
}

?>